@@ -20,6 +20,8 @@ package org.apache.tools.ant.taskdefs.compilers;
 
 import java.io.File;
 import java.io.IOException;
+import java.util.Arrays;
+import java.util.List;
 
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
@@ -66,7 +68,7 @@ public class JavacExternal extends DefaultCompilerAdapter {
         int firstFileName;
 
         if (assumeJava1_2Plus()) {
-            firstFileName = moveJOptionsToBeginning(commandLine);
+            firstFileName = moveArgFileEligibleOptionsToEnd(commandLine);
         } else {
             firstFileName = -1;
         }
@@ -77,31 +79,77 @@ public class JavacExternal extends DefaultCompilerAdapter {
     }
 
     /**
-     * Moves all -J arguments to the beginning
-     * So that all command line arguments could be written to file, but -J
+     * Moves all -J and @argfiles arguments to the beginning
+     * So that all command line arguments could be written to file, but -J and @argfile
      * As per javac documentation:
      *      you can specify one or more files that contain arguments to the javac command (except -J options)
      * @param commandLine command line to process
-     * @return int index of first non -J argument
+     * @return int index of first argument that could be put into argfile
      */
-    private int moveJOptionsToBeginning(String[] commandLine) {
-        int nonJArgumentIdx = 1; // 0 for javac executable
-        while(nonJArgumentIdx < commandLine.length && commandLine[nonJArgumentIdx].startsWith("-J")) {
-            nonJArgumentIdx++;
-        }
-
-        for(int i = nonJArgumentIdx + 1; i < commandLine.length; i++) {
-            if (commandLine[i].startsWith("-J")) {
-                String jArgument = commandLine[i];
-                for(int j = i - 1; j >= nonJArgumentIdx; j--) {
-                    commandLine[j + 1] = commandLine[j];
-                }
-                commandLine[nonJArgumentIdx] = jArgument;
-                nonJArgumentIdx++;
+    private int moveArgFileEligibleOptionsToEnd(String[] commandLine) {
+        int nonArgFileOptionIdx = 1; // 0 for javac executable
+        while (nonArgFileOptionIdx < commandLine.length) {
+            int argsToMove = numberOfArgsNotEligibleForFile(commandLine, nonArgFileOptionIdx);
+            if (argsToMove > 0) {
+                nonArgFileOptionIdx += argsToMove;
+            } else {
+                break;
             }
         }
 
-        return nonJArgumentIdx;
+        for(int i = nonArgFileOptionIdx + 1; i < commandLine.length; i++) {
+            int argsToMove = numberOfArgsNotEligibleForFile(commandLine, i);
+            if (argsToMove > 0) {
+                String[] options = Arrays.copyOfRange(commandLine, i, i + argsToMove);
+                if (i - nonArgFileOptionIdx >= 0) {
+                    System.arraycopy( commandLine, nonArgFileOptionIdx, commandLine, nonArgFileOptionIdx + argsToMove, i - nonArgFileOptionIdx );
+                }
+                System.arraycopy(options, 0, commandLine, nonArgFileOptionIdx, argsToMove);
+                nonArgFileOptionIdx += argsToMove;
+                i += argsToMove - 1;
+            }
+        }
+
+        return nonArgFileOptionIdx;
+    }
+
+    private static int numberOfArgsNotEligibleForFile(String[] args, int currentIndex) {
+        String currentOption = args[currentIndex];
+        if (!isArgFileEligible(currentOption)) {
+            return 1;
+        }
+        if (currentIndex + 1 < args.length && isArgFollowedByPath(currentOption)
+            && containsWildcards(args[currentIndex + 1])) {
+            return 2;
+        }
+        return 0;
+    }
+
+    private static boolean containsWildcards(String path) {
+        return path.contains("*") || path.contains("?");
+    }
+
+    private static boolean isArgFileEligible(String option) {
+        return !(option.startsWith("-J") || option.startsWith("@")
+            || (option.startsWith("-Xbootclasspath/") && containsWildcards(option))
+        );
+    }
+
+    private static List<String> ARGS_FOLLOWED_BY_PATH = Arrays.asList(
+        "-cp", "-classpath", "--class-path",
+        "-endorseddirs",
+        "-extdirs",
+        "--module-path", "-p",
+        "--module-source-path",
+        "--processor-module-path",
+        "--processor-path", "-processorpath",
+        "-sourcepath", "--source-path",
+        "-bootclasspath", "--boot-class-path",
+        "--upgrade-module-path"
+    );
+
+    private static boolean isArgFollowedByPath(String option) {
+        return ARGS_FOLLOWED_BY_PATH.contains(option);
     }
 
     /**
