@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,7 +20,8 @@ package org.apache.tools.ant.types.selectors.modifiedselector;
 
 
 import java.io.File;
-import java.io.FileInputStream;
+import java.io.IOException;
+import java.nio.file.Files;
 import java.security.DigestInputStream;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
@@ -33,23 +34,24 @@ import org.apache.tools.ant.BuildException;
 /**
  * Computes a 'hashvalue' for the content of file using
  * java.security.MessageDigest.
- * Use of this algorithm doesn't require any additional nested <param>s.
- * Supported <param>s are:
+ * Use of this algorithm doesn't require any additional nested &lt;param&gt;s.
+ * Supported &lt;param&gt;s are:
  * <table>
+ * <caption>Digest algorithm parameters</caption>
  * <tr>
  *   <th>name</th><th>values</th><th>description</th><th>required</th>
  * </tr>
  * <tr>
- *   <td> algorithm.algorithm </td>
- *   <td> MD5 | SHA (default provider) </td>
- *   <td> name of the algorithm the provider should use </td>
- *   <td> no, defaults to MD5 </td>
+ *   <td>algorithm.algorithm</td>
+ *   <td>MD5 | SHA (default provider)</td>
+ *   <td>name of the algorithm the provider should use</td>
+ *   <td>no, defaults to MD5</td>
  * </tr>
  * <tr>
- *   <td> algorithm.provider </td>
- *   <td> </td>
- *   <td> name of the provider to use </td>
- *   <td> no, defaults to <i>null</i> </td>
+ *   <td> algorithm.provider</td>
+ *   <td></td>
+ *   <td>name of the provider to use</td>
+ *   <td>no, defaults to <i>null</i></td>
  * </tr>
  * </table>
  *
@@ -115,13 +117,11 @@ public class DigestAlgorithm implements Algorithm {
             return;
         }
 
-        if ((provider != null) && !"".equals(provider) && !"null".equals(provider)) {
+        if (provider != null && !provider.isEmpty() && !"null".equals(provider)) {
             try {
                 messageDigest = MessageDigest.getInstance(algorithm, provider);
-            } catch (NoSuchAlgorithmException noalgo) {
-                throw new BuildException(noalgo);
-            } catch (NoSuchProviderException noprovider) {
-                throw new BuildException(noprovider);
+            } catch (NoSuchAlgorithmException | NoSuchProviderException e) {
+                throw new BuildException(e);
             }
         } else {
             try {
@@ -140,69 +140,47 @@ public class DigestAlgorithm implements Algorithm {
      * This algorithm supports only MD5 and SHA.
      * @return <i>true</i> if all is ok, otherwise <i>false</i>.
      */
+    @Override
     public boolean isValid() {
         return "SHA".equals(algorithm) || "MD5".equals(algorithm);
     }
 
-
     /**
      * Computes a value for a file content with the specified digest algorithm.
      * @param file    File object for which the value should be evaluated.
      * @return        The value for that file
      */
     // implementation adapted from ...taskdefs.Checksum, thanks to Magesh for hint
+    @Override
     public String getValue(File file) {
+        if (!file.canRead()) {
+            return null;
+        }
         initMessageDigest();
-        String checksum = null;
-        try {
-            if (!file.canRead()) {
-                return null;
+        byte[] buf = new byte[readBufferSize];
+        messageDigest.reset();
+        try (DigestInputStream dis = new DigestInputStream(Files.newInputStream(file.toPath()),
+                messageDigest)) {
+            // read the whole stream
+            while (dis.read(buf, 0, readBufferSize) != -1) {
             }
-            FileInputStream fis = null;
-
-            byte[] buf = new byte[readBufferSize];
-            try {
-                messageDigest.reset();
-                fis = new FileInputStream(file);
-                DigestInputStream dis = new DigestInputStream(fis,
-                                                              messageDigest);
-                while (dis.read(buf, 0, readBufferSize) != -1) {
-                    // do nothing
-                }
-                dis.close();
-                fis.close();
-                fis = null;
-                byte[] fileDigest = messageDigest.digest();
-                StringBuffer checksumSb = new StringBuffer();
-                for (int i = 0; i < fileDigest.length; i++) {
-                    String hexStr
-                        = Integer.toHexString(BYTE_MASK & fileDigest[i]);
-                    if (hexStr.length() < 2) {
-                        checksumSb.append("0");
-                    }
-                    checksumSb.append(hexStr);
-                }
-                checksum = checksumSb.toString();
-            } catch (Exception e) {
-                return null;
+            StringBuilder checksumSb = new StringBuilder();
+            for (byte digestByte : messageDigest.digest()) {
+                checksumSb.append(String.format("%02x", BYTE_MASK & digestByte));
             }
-        } catch (Exception e) {
+            return checksumSb.toString();
+        } catch (IOException ignored) {
             return null;
         }
-        return checksum;
     }
 
-
     /**
      * Override Object.toString().
      * @return some information about this algorithm.
      */
+    @Override
     public String toString() {
-        StringBuilder buf = new StringBuilder();
-        buf.append("<DigestAlgorithm:");
-        buf.append("algorithm=").append(algorithm);
-        buf.append(";provider=").append(provider);
-        buf.append(">");
-        return buf.toString();
+        return String.format("<DigestAlgorithm:algorithm=%s;provider=%s>",
+            algorithm, provider);
     }
 }
