@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,6 +23,7 @@ import java.util.Map;
 
 import org.apache.tools.ant.AntClassLoader;
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.MagicNames;
 
 
 /**
@@ -31,7 +32,7 @@ import org.apache.tools.ant.BuildException;
  */
 public class ScriptFixBSFPath {
     private static final String UTIL_OPTIONAL_PACKAGE
-        = "org.apache.tools.ant.util.optional";
+        = MagicNames.ANT_CORE_PACKAGE + ".util.optional";
 
     private static final String BSF_PACKAGE = "org.apache.bsf";
     private static final String BSF_MANAGER = BSF_PACKAGE + ".BSFManager";
