@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -25,7 +25,7 @@ package org.apache.tools.tar;
 
 import java.io.File;
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
+import java.nio.charset.StandardCharsets;
 import java.util.Date;
 import java.util.Locale;
 
@@ -395,6 +395,26 @@ public class TarEntry implements TarConstants {
         this.mode = mode;
     }
 
+    /**
+     * Get this entry's link flag.
+     *
+     * @return This entry's link flag.
+     * @since 1.10.12
+     */
+    public byte getLinkFlag() {
+        return linkFlag;
+    }
+
+    /**
+     * Set this entry's link flag.
+     *
+     * @param link the link flag to use.
+     * @since 1.10.12
+     */
+    public void setLinkFlag(byte linkFlag) {
+        this.linkFlag = linkFlag;
+    }
+
     /**
      * Get this entry's link name.
      *
@@ -804,6 +824,9 @@ public class TarEntry implements TarConstants {
         }
 
         String[]   list = file.list();
+        if (list == null) {
+            return new TarEntry[0];
+        }
         TarEntry[] result = new TarEntry[list.length];
 
         for (int i = 0; i < list.length; ++i) {
@@ -1072,13 +1095,7 @@ public class TarEntry implements TarConstants {
      */
     private static boolean matchAsciiBuffer(String expected, byte[] buffer,
                                             int offset, int length) {
-        byte[] buffer1;
-        try {
-            buffer1 = expected.getBytes("ASCII");
-        } catch (UnsupportedEncodingException e) {
-            // Should not happen
-            throw new RuntimeException(e); //NOSONAR
-        }
+        byte[] buffer1 = expected.getBytes(StandardCharsets.US_ASCII);
         return isEqual(buffer1, 0, buffer1.length, buffer, offset, length,
                        false);
     }
