@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -235,7 +235,7 @@ public class AntTest {
                 buildRule.getProject().resolveFile("ant/test3.log"),
                 buildRule.getProject().resolveFile("ant/test4.log"));
 
-        logFiles.forEach(logFile -> assertFalse(logFile.getName() + " doesn\'t exist",
+        logFiles.forEach(logFile -> assertFalse(logFile.getName() + " doesn't exist",
                 logFile.exists()));
 
         buildRule.executeTarget("testLogfilePlacement");
@@ -461,7 +461,7 @@ public class AntTest {
             }
             if (error == null) {
                 try {
-                    String msg = "Call " + calls + " refid=\'" + keys[calls] + "\'";
+                    String msg = "Call " + calls + " refid='" + keys[calls] + "'";
                     if (value == null) {
                         Object o = event.getProject().getReference(keys[calls]);
                         if (expectSame[calls++]) {
